@@ -3,7 +3,8 @@ from enum import Enum
 
 class Profile:
 
-    def __init__(self, assetId, createdAt, id, jobId, profilingType, sparkClusterContext, status, updatedAt, rows=None,
+    def __init__(self, assetId, createdAt, id, jobId=None, profilingType=None, sparkClusterContext=None, status=None,
+                 updatedAt=None, rows=None,
                  totalRows=None, jobType=None, autoProfileId=None, profileDataAvailable=None, marker=None,
                  profiledData=None, error=None, client=None, *args, **kwargs):
         self.client = client
@@ -33,36 +34,6 @@ class Profile:
     def get_status(self):
         return self.client.get_profile_request_details(asset_id=self.assetId, req_id=self.id)
 
-
-class AutoProfileConfiguration:
-
-    def __init__(self, assemblyId, assemblyName, createdAt, updatedAt, enabled, schedule, parallelizationCount, id=None,
-                 includeList=None, excludeList=None, *args, **kwargs):
-        self.assemblyId = assemblyId
-        self.assemblyName = assemblyName
-        self.createdAt = createdAt
-        self.updatedAt = updatedAt
-        self.enabled = enabled
-        self.schedule = schedule
-        self.parallelizationCount = parallelizationCount
-        self.id = id
-        if isinstance(includeList, list):
-            self.includeList = list(includeList)
-        else:
-            self.includeList = includeList
-
-        if isinstance(excludeList, dict):
-            self.excludeList = list(excludeList)
-        else:
-            self.excludeList = excludeList
-
-    def __eq__(self, other):
-        return self.id == other.id
-
-    def __repr__(self):
-        return f"AutoProfileConfiguration({self.__dict__})"
-
-
 class ProfilingType(Enum):
     SAMPLE = 'SAMPLE'
     FULL = 'FULL'
@@ -77,12 +48,15 @@ class JobType(Enum):
 
 class ProfileRequest:
 
-    def __init__(self, id, status, createdAt, updatedAt, client=None, *args, **kwargs):
+    def __init__(self, id, status, createdAt=None, updatedAt=None, client=None, totalRows=None, isProfileAnomalous=None,
+                 *args, **kwargs):
         self.client = client
         self.updatedAt = updatedAt
         self.createdAt = createdAt
         self.status = status
         self.id = id
+        self.totalRows = totalRows
+        self.isProfileAnomalous = isProfileAnomalous
 
     def __repr__(self):
         return f"ProfileRequest({self.__dict__})"
