@@ -78,6 +78,32 @@ class LivyExecutorConfig:
         return f"LivyExecutorConfig({self.__dict__})"
 
 
+class DataprocSparkResourceConfig:
+    def __init__(self, numWorkerNodes=None, numMasterNodes=None, clusterWorkerType=None, clusterMasterType=None, *args,
+                 **kwargs):
+        self.numWorkerNodes = numWorkerNodes
+        self.numMasterNodes = numMasterNodes
+        self.clusterWorkerType = clusterWorkerType
+        self.clusterMasterType = clusterMasterType
+
+    def __repr__(self):
+        return f"DataprocSparkResourceConfig({self.__dict__})"
+
+
+class YunikornSparkResourceConfig:
+    def __init__(self, executorMemory=None, executorCores=None, maxExecutors=None, minExecutors=None,
+                 executorMemoryOverhead=None, driverMemory=None,
+                 driverCores=None, driverMemoryOverhead=None):
+        self.executorMemory = executorMemory
+        self.executorCores = executorCores
+        self.maxExecutors = maxExecutors
+        self.minExecutors = minExecutors
+        self.executorMemoryOverhead = executorMemoryOverhead
+        self.driverMemory = driverMemory
+        self.driverCores = driverCores
+        self.driverMemoryOverhead = driverMemoryOverhead
+
+
 class DataBricksExecutorConfig:
     def __init__(self, minWorkers=None, maxWorkers=None, clusterWorkerType=None, clusterDriverType=None, *args, **kwargs):
         self.minWorkers = minWorkers
@@ -90,7 +116,8 @@ class DataBricksExecutorConfig:
 
 
 class ExecutorConfig:
-    def __init__(self, livy=None, databricks=None, *args, **kwargs):
+    def __init__(self, livy=None, databricks=None, dataproc=None, yunikorn=None, additionalConfiguration=None, *args,
+                 **kwargs):
         if isinstance(livy, dict):
             self.livy = LivyExecutorConfig(**livy)
         else:
@@ -99,10 +126,44 @@ class ExecutorConfig:
             self.databricks = DataBricksExecutorConfig(**databricks)
         else:
             self.databricks = databricks
+        if isinstance(dataproc, dict):
+            self.dataproc = DataprocSparkResourceConfig(**databricks)
+        else:
+            self.dataproc = dataproc
+        if isinstance(yunikorn, dict):
+            self.yunikorn = YunikornSparkResourceConfig(**databricks)
+        else:
+            self.yunikorn = yunikorn
+        self.additionalConfiguration = additionalConfiguration
+
 
     def __repr__(self):
         return f"ExecutorConfig({self.__dict__})"
 
+class SparkResourceConfig:
+    def __init__(self, livy=None, databricks=None, dataproc=None, yunikorn=None, additionalConfiguration=None, *args,
+                 **kwargs):
+        if isinstance(livy, dict):
+            self.livy = LivyExecutorConfig(**livy)
+        else:
+            self.livy = livy
+        if isinstance(databricks, dict):
+            self.databricks = DataBricksExecutorConfig(**databricks)
+        else:
+            self.databricks = databricks
+        if isinstance(dataproc, dict):
+            self.dataproc = DataprocSparkResourceConfig(**databricks)
+        else:
+            self.dataproc = dataproc
+        if isinstance(yunikorn, dict):
+            self.yunikorn = YunikornSparkResourceConfig(**databricks)
+        else:
+            self.yunikorn = yunikorn
+        self.additionalConfiguration = additionalConfiguration
+
+
+    def __repr__(self):
+        return f"ExecutorConfig({self.__dict__})"
 
 class RuleExecutionSummary:
     def __init__(self, ruleId=None, executionMode=None, executionStatus=None, resultStatus=None, startedAt=None,
@@ -110,7 +171,7 @@ class RuleExecutionSummary:
                  lastMarker=None, leftLastMarker=None, rightLastMarker=None, executionError=None, finishedAt=None,
                  resetPoint=None, persistencePath=None, resultPersistencePath=None, executorConfig=None,
                  markerConfig=None, leftMarkerConfig=None, rightMarkerConfig=None, dataPersistenceEnabled=None,
-                 isProtectedResource=None, *args, **kwargs):
+                 isProtectedResource=None, sparkResourceConfig=None, *args, **kwargs):
 
         self.ruleId = ruleId
         self.id = id
@@ -151,6 +212,12 @@ class RuleExecutionSummary:
             self.executorConfig = ExecutorConfig(**executorConfig)
         else:
             self.executorConfig = executorConfig
+
+        if isinstance(sparkResourceConfig, dict):
+            self.sparkResourceConfig = SparkResourceConfig(**executorConfig)
+        else:
+            self.sparkResourceConfig = sparkResourceConfig
+
         self.markerConfig = markerConfig
         self.leftMarkerConfig = leftMarkerConfig
         self.rightMarkerConfig = rightMarkerConfig
@@ -178,11 +245,10 @@ class RuleExecutionResult:
 
 
 class RuleItemResult:
-    def __init__(self, id, ruleItemId, threshold, weightage, isWarning, resultPercent=None, businessItemId=None,
-                 success=None, error=None, *args, **kwargs):
+    def __init__(self, id, ruleItemId, threshold, weightage, isWarning, resultPercent=None, success=None, error=None,
+                 *args, **kwargs):
         self.id = id
         self.ruleItemId = ruleItemId
-        self.businessItemId = businessItemId
         self.threshold = threshold
         self.resultPercent = resultPercent
         self.success = success
