@@ -43,14 +43,38 @@ pipeline_api_path = "/torch-pipeline/api"
 admin_api_path = "/admin/api"
 
 import urllib3
+import re
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
+def _has_leading_zero(value):
+    return (value
+            and value[0] == '0'
+            and value.isdigit()
+            and value != '0')
+
 
 def extract_actual_version(torch_version) -> str:
     if torch_version.buildVersion:
-        parsed_version = Version(torch_version.buildVersion)
-        actual_version = f'{parsed_version.major}.{parsed_version.minor}.{parsed_version.patch}'
+        version_string =torch_version.buildVersion
+        version_re = re.compile(r'^(\d+)(?:\.(\d+)(?:\.(\d+))?)?(?:-(.*))?$')
+        match = version_re.match(version_string)
+        if not match:
+            raise ValueError('Invalid version string: %r' % version_string)
+
+        major, minor, patch, others = match.groups()
+
+        if _has_leading_zero(major):
+            raise ValueError("Invalid leading zero in major: %r" % version_string)
+        if _has_leading_zero(minor):
+            raise ValueError("Invalid leading zero in minor: %r" % version_string)
+        if _has_leading_zero(patch):
+            raise ValueError("Invalid leading zero in patch: %r" % version_string)
+
+        major = int(major)
+        minor = int(minor)
+        patch = int(patch)
+        actual_version = f'{major}.{minor}.{patch}'
         return actual_version
     else:
         raise TorchSdkException(f'Torch version is not available.')
@@ -121,11 +145,11 @@ def calculate_months_before_time(months_before):
     """
     now = datetime.now()
     first_day_of_months_before = (now - relativedelta(months=months_before)).replace(day=1, hour=0, minute=0, second=0,
-                                                                       microsecond=0)
+                                                                                     microsecond=0)
     last_day_of_prev_month = now.replace(day=1, hour=0, minute=0, second=0, microsecond=0)
     started_after_time = first_day_of_months_before
     finished_before_time = last_day_of_prev_month
-    return started_after_time,finished_before_time
+    return started_after_time, finished_before_time
 
 
 def calculate_time_range(filter):
@@ -386,38 +410,18 @@ class TorchHttpClient(TorchClientInterFace, ABC):
         :param pipeline_id: id of the pipeline. This is a mandatory parameter when run is being queried using continuation_id
         :return: PipelineRun instance
         """
-        payload = dict()
-        return_run = dict()
         if pipeline_run_id is not None:
             url = f'{self._pipeline_api_base}/pipelines/runs/{pipeline_run_id}'
             response = self._get(url)
             return_run = response['run']
         elif continuation_id is not None and pipeline_id is not None:
-            supported_versions = self.get_supported_sdk_versions()
-            torch_version: str = self.get_torch_version()
-            if torch_version.buildVersion is not None and torch_version.buildVersion != "":
-                # Parse the semantic version string
-                parsed_version = semantic_version.Version(torch_version.buildVersion)
-                actual_version = f'{parsed_version.major}.{parsed_version.minor}.{parsed_version.patch}'
+            url = f'{self._pipeline_api_base}/pipelines/{pipeline_id}/runs'
+            payload = {"continuationId": continuation_id}
+            response = self._get(url, params=payload)
+            if response["runs"] is not None and len(response["runs"]) > 0:
+                return_run = response["runs"][0]
             else:
-                actual_version = supported_versions.maxVersion
-            ver_comparator = SimpleSpec(f'<={actual_version}')
-            if Version('2.5.0') in ver_comparator:
-                url = f'{self._pipeline_api_base}/pipelines/{pipeline_id}/runs'
-                payload = {"continuationId": continuation_id}
-                response = self._get(url, params=payload)
-                if response["runs"] is not None and len(response["runs"]) > 0:
-                    return_run = response["runs"][0]
-                else:
-                    raise TorchSdkException('No runs found against the given continuation_id.')
-            else:
-                # For torch versions lower than 2.5.0 use old call for continuation_id
-                if continuation_id.isdigit() is False:
-                    url = f'{self._pipeline_api_base}/pipelines/runs/{continuation_id}'
-                    response = self._get(url)
-                    return_run = response['run']
-                else:
-                    raise TorchSdkException('Please provide continuation_id which is not a valid number.')
+                raise TorchSdkException('No runs found against the given continuation_id.')
         else:
             raise TorchSdkException('Please provide either continuation_id and pipeline_id or pipeline_run_id')
 
@@ -704,8 +708,14 @@ class TorchHttpClient(TorchClientInterFace, ABC):
             raise Exception('Asset uid is required')
         url = f'{self._catalog_api_base}/assets?uid={uid}'
         asset = self._get_asset(url)
-        asset['data']['client'] = self
-        return Asset(**asset['data'])
+        if asset is None:
+            return None
+        asset_data = asset['data']
+        if asset_data is None or not asset_data or len(asset_data) == 0:
+            return None
+        asset_res = list(asset_data)[0]
+        asset_res['client'] = self
+        return Asset(**asset_res)
 
     def _get_asset(self, url: str):
         response = self._get(
@@ -760,11 +770,11 @@ class TorchHttpClient(TorchClientInterFace, ABC):
 
 
     def get_sample_data_result(self, request_id: str):
-            url = f'{self._catalog_api_base}/assets/sample/result/{request_id}'
-            response = self._get(
-                url=url
-            )
-            return response
+        url = f'{self._catalog_api_base}/assets/sample/result/{request_id}'
+        response = self._get(
+            url=url
+        )
+        return response
 
     def get_profile_request_details(self, asset_id: int, req_id: int):
         url = f'{self._catalog_api_base}/assets/{asset_id}/profile/{req_id}'
